###############################
Segments (:mod:`gwpy.segments`)
###############################

.. automodule:: gwpy.segments

.. seealso::

    - **User Guide**: :doc:`/segments/index`
    - **Examples**: :doc:`/examples/segments/index`

.. automodapi:: gwpy.segments
    :include-all-objects:
    :no-heading:
    :no-main-docstr:
